@@ -4,11 +4,19 @@
 
 namespace Icinga\Module\Cube;
 
+use Icinga\Application\Modules\Module;
 use Icinga\Exception\IcingaException;
+use Icinga\Module\Cube\ProvidedHook\Icingadb\IcingadbSupport;
 use Icinga\Web\View;
 
 abstract class Cube
 {
+    /** @var string Prefix for slice params */
+    public const SLICE_PREFIX = null;
+
+    /** @var bool Whether the icingadb backend is in use */
+    public const IS_USING_ICINGADB = null;
+
     /** @var array<string, Dimension> Available dimensions */
     protected $availableDimensions;
 
@@ -24,6 +32,17 @@ abstract class Cube
 
     abstract public function fetchAll();
 
+    /**
+     * Get whether the icingadb backend is in use
+     *
+     * @return bool
+     */
+    public static function isUsingIcingaDb(): bool
+    {
+        return static::IS_USING_ICINGADB
+            ?? (Module::exists('icingadb') && IcingadbSupport::useIcingaDbAsBackend());
+    }
+
     public function removeDimension($name)
     {
         unset($this->dimensions[$name]);
@@ -98,8 +117,7 @@ abstract class Cube
         }
 
         $this->availableDimensions = [];
-        foreach ($this->listAvailableDimensions() as $label) {
-            $name = strtolower($label);
+        foreach ($this->listAvailableDimensions() as $name => $label) {
             if (! isset($this->availableDimensions[$name])) {
                 $this->availableDimensions[$name] = $this->createDimension($name)->setLabel($label);
             } else {
@@ -226,7 +244,7 @@ abstract class Cube
     public function addDimension(Dimension $dimension)
     {
         $name = $dimension->getName();
-        if (array_key_exists($name, $this->dimensions)) {
+        if ($this->hasDimension($name)) {
             throw new IcingaException('Cannot add dimension "%s" twice', $name);
         }
 
