@@ -5,10 +5,10 @@
 namespace Icinga\Module\Cube\IcingaDb;
 
 use Icinga\Module\Cube\CubeRenderer\HostStatusCubeRenderer;
-use Icinga\Module\Icingadb\Model\CustomvarFlat;
 use Icinga\Module\Icingadb\Model\Host;
 use Icinga\Module\Icingadb\Model\HoststateSummary;
 use ipl\Stdlib\Filter;
+use ipl\Stdlib\Str;
 
 class IcingaDbHostStatusCube extends IcingaDbCube
 {
@@ -41,25 +41,7 @@ class IcingaDbHostStatusCube extends IcingaDbCube
 
     public function listAvailableDimensions()
     {
-        $db = $this->getDb();
-
-        $query = CustomvarFlat::on($db);
-        $this->applyRestrictions($query);
-
-        $query
-            ->columns('flatname')
-            ->orderBy('flatname')
-            ->filter(Filter::like('host.id', '*'));
-        $query->getSelectBase()->groupBy('flatname');
-
-        $dimensions = [];
-        foreach ($query as $row) {
-            // Replaces array index notations with [*] to get results for arbitrary indexes
-            $name = preg_replace('/\\[\d+](?=\\.|$)/', '[*]', $row->flatname);
-            $dimensions[$name] = $name;
-        }
-
-        return $dimensions;
+        return $this->fetchHostVariableDimensions();
     }
 
     public function prepareInnerQuery()
